@@ -5,18 +5,18 @@ import sys
 
 from typing import List
 
-from lintian_brush.control import (
+from debmutate.control import (
     ensure_exact_version,
     iter_relations,
     is_relation_implied,
-    ControlUpdater,
+    ControlEditor,
     parse_relations,
     format_relations,
     )
-from lintian_brush.debhelper import (
+from debmutate.debhelper import (
     read_debhelper_compat_file,
     )
-from lintian_brush.fixer import report_result
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 from lintian_brush.rules import (
     check_cdbs,
     )
@@ -40,7 +40,7 @@ if debhelper_compat_version < 11 or check_cdbs():
 os.unlink('debian/compat')
 
 # Assume that the compat version is set in Build-Depends
-with ControlUpdater() as updater:
+with ControlEditor() as updater:
     insert_position = None
     changed_fields = []
     for field in ['Build-Depends', 'Build-Depends-Indep',
@@ -76,11 +76,10 @@ with ControlUpdater() as updater:
     updater.source["Build-Depends"] = ensure_exact_version(
         updater.source.get("Build-Depends", ""), "debhelper-compat",
         "%d" % debhelper_compat_version, position=insert_position)
+    fixed_lintian_tag(updater.source, 'uses-debhelper-compat-file', ())
 
     for field in changed_fields:
         if updater.source.get(field) == "":
             del updater.source[field]
 
-report_result(
-    "Set debhelper-compat version in Build-Depends.",
-    fixed_lintian_tags=['uses-debhelper-compat-file'])
+report_result("Set debhelper-compat version in Build-Depends.")
