@@ -22,23 +22,18 @@ def test_suite():
     names = [
         'changelog',
         'config',
-        'control',
-        'copyright',
-        'deb822',
         'debhelper',
         'detect_gbp_dch',
         'dirty_tracker',
         'lintian_overrides',
         'multiarch_hints',
         'patches',
-        'reformatting',
         'rules',
         'run',
         'salsa',
         'systemd',
         'upstream_metadata',
         'vcs',
-        'watch',
         'xdg',
         'yaml',
         ]
