@@ -331,6 +331,8 @@ def known_bad_guess(datum):
         parsed_url = urlparse(datum.value)
         if parsed_url.hostname == 'anongit.kde.org':
             return True
+        if parsed_url.hostname == 'git.gitorious.org':
+            return True
     if datum.field == 'Repository-Browse':
         parsed_url = urlparse(datum.value)
         if parsed_url.hostname == 'cgit.kde.org':
@@ -769,7 +771,9 @@ def guess_from_readme(path, trust_package):
                     if is_gitlab_site(m.group(1).decode()):
                         url = m.group(0).rstrip(b'.').decode().rstrip()
                         repo_url = guess_repo_from_url(url)
-                        yield UpstreamDatum('Repository', repo_url, 'possible')
+                        if repo_url:
+                            yield UpstreamDatum(
+                                'Repository', repo_url, 'possible')
     except IsADirectoryError:
         pass
 
